==> simplenotewidget_0.3-09.tar.gz: simplenotewidget-0.3/src/simplenotewidget_bg_BG.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>Dialog</name>
    <message>
        <location filename="dialog.ui" line="43"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialog.ui" line="56"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialog.ui" line="69"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialog.cpp" line="32"/>
        <source>Edit note</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="40"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="53"/>
        <source>cc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="173"/>
        <source>please press twice for the edit mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtColorComboBox</name>
    <message>
        <location filename="qtcolorcombobox.cpp" line="131"/>
        <source>More...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="232"/>
        <source>User color %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="276"/>
        <source>User Color 99</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="290"/>
        <source>Black</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="291"/>
        <source>White</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="292"/>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="293"/>
        <source>Dark red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="294"/>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="295"/>
        <source>Dark green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="296"/>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="297"/>
        <source>Dark blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="298"/>
        <source>Cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="299"/>
        <source>Dark cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="300"/>
        <source>Magenta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="301"/>
        <source>Dark magenta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="302"/>
        <source>Yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="303"/>
        <source>Dark yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="304"/>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="305"/>
        <source>Dark gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="306"/>
        <source>Light gray</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <location filename="settingswidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="26"/>
        <source>Transparency:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="39"/>
        <source>Text color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="52"/>
        <source>Background color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="95"/>
        <source>Font-Family:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="108"/>
        <source>Font-Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="121"/>
        <source>Use System Colors:</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>settingsdlg</name>
    <message>
        <location filename="settingsdlg.ui" line="26"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdlg.ui" line="39"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdlg.cpp" line="16"/>
        <source>Edit settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> simplenotewidget_0.3-10.tar.gz: simplenotewidget-0.3/src/simplenotewidget_bg_BG.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="bg_BG">
<context>
    <name>Dialog</name>
    <message>
        <location filename="dialog.ui" line="43"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialog.ui" line="56"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialog.ui" line="69"/>
        <source>Clear</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="dialog.cpp" line="32"/>
        <source>Edit note</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <location filename="mainwindow.ui" line="14"/>
        <source>MainWindow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="40"/>
        <source>TextLabel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.ui" line="53"/>
        <source>cc</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="mainwindow.cpp" line="176"/>
        <source>please press twice for the edit mode</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>QtColorComboBox</name>
    <message>
        <location filename="qtcolorcombobox.cpp" line="131"/>
        <source>More...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="232"/>
        <source>User color %1</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="276"/>
        <source>User Color 99</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="290"/>
        <source>Black</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="291"/>
        <source>White</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="292"/>
        <source>Red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="293"/>
        <source>Dark red</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="294"/>
        <source>Green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="295"/>
        <source>Dark green</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="296"/>
        <source>Blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="297"/>
        <source>Dark blue</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="298"/>
        <source>Cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="299"/>
        <source>Dark cyan</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="300"/>
        <source>Magenta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="301"/>
        <source>Dark magenta</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="302"/>
        <source>Yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="303"/>
        <source>Dark yellow</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="304"/>
        <source>Gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="305"/>
        <source>Dark gray</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="qtcolorcombobox.cpp" line="306"/>
        <source>Light gray</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <location filename="settingswidget.ui" line="14"/>
        <source>Form</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="26"/>
        <source>Transparency:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="39"/>
        <source>Text color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="52"/>
        <source>Background color:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="95"/>
        <source>Font-Family:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="108"/>
        <source>Font-Size:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="121"/>
        <source>Use System Colors:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.ui" line="147"/>
        <source>Language:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.cpp" line="64"/>
        <source>System</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.cpp" line="172"/>
        <source>Language changed</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.cpp" line="172"/>
        <source>Changing the language requires a restart of the widget.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingswidget.cpp" line="172"/>
        <source>OK</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>settingsdlg</name>
    <message>
        <location filename="settingsdlg.ui" line="26"/>
        <source>Save</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdlg.ui" line="39"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="settingsdlg.cpp" line="16"/>
        <source>Edit settings</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
